==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-sensors/sensors_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <source>LXQt Sensors Settings</source>
        <translation type="vanished">Ρυθμίσεις αισθητήρων LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Ρυθμίσεις αισθητήρων</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Κοινές επιλογές</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Διάστημα ανανέωσης (δευτερόλεπτα)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Πλάτος γραμμής θερμοκρασίας</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Κλίμακα θερμοκρασίας</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Κελσίου</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Φαρενάιτ</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Αναβόσβημα γραμμών προόδου, ​​όταν η θερμοκρασία είναι πολύ υψηλή</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Προειδοποίηση υψηλής θερμοκρασίας</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Αισθητήρες</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Ανιχνευμένα κυκλώματα:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Χαρακτηριστικά κυκλώματος:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="212"/>
        <source>Enabled</source>
        <translation>Ενεργοποιημένο</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="212"/>
        <source>Label</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="212"/>
        <source>Color</source>
        <translation>Χρώμα</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-sensors/sensors_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <source>LXQt Sensors Settings</source>
        <translation>Ρυθμίσεις αισθητήρων του LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Ρυθμίσεις αισθητήρων</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Κοινές επιλογές</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Διάστημα ανανέωσης (δευτερόλεπτα)</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Πλάτος γραμμής θερμοκρασίας</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Κλίμακα θερμοκρασίας</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Κελσίου</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Φαρενάιτ</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink progress bars when the temperature is too high</source>
        <translation>Αναβόσβημα γραμμών προόδου, ​​όταν η θερμοκρασία είναι πολύ υψηλή</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Προειδοποίηση υψηλής θερμοκρασίας</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Αισθητήρες</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Ανιχνευμένα κυκλώματα:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Χαρακτηριστικά κυκλώματος:</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>Ενεργοποιημένο</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <location filename="../../../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>Χρώμα</translation>
    </message>
</context>
</TS>
